@@ -1,4 +1,4 @@
-.onLoad <- function(lib, pkg){
+.onAttach <- function(lib, pkg){
   Sys.setenv(TZ='UTC')
   packageStartupMessage('Time Zone set to UTC.\n')
 }
